# Combinatorics Package

This is a simple combinatorics package which offers combinations and permutations functions. 

# Importing

You can import the factorial package by:
``` 
from combinatorics_tb import combinatorics
```

# Using Combinatorics

You can use the combinations (where order doesn't matter) command using:
```
combinatorics.combinations(52, 2)
```
which will output 1326.

You can use the permutations (where order does matter) command using:
```
combinatorics.permutations(52, 2)
```
which will output 2652.
